<?php
// Feed-URL hier eintragen:
$feedUrl = 'https://www.sgs-visual.de/ast/feed/feed/feed.xml'; // <-- HIER ANPASSEN

// Feed laden
$feedItems = [];
$feedTitle = '';
$feedError = '';
if ($feedUrl) {
    $feedContent = @file_get_contents($feedUrl);
    if ($feedContent !== false) {
        $rss = @simplexml_load_string($feedContent);
        if ($rss !== false && isset($rss->channel)) {
            $feedTitle = (string)$rss->channel->title;
            foreach ($rss->channel->item as $item) {
                $description = (string)$item->description;

                // Bild extrahieren
                $imgTag = '';
                if (preg_match('/<img[^>]+src="([^"]+)"[^>]*>/i', $description, $matches)) {
                    $imgSrc = $matches[1];
                    $imgTag = '<img src="' . htmlspecialchars($imgSrc) . '" alt="" style="max-width:200px;height:auto;display:block;margin-bottom:10px;" />';
                    // Bild aus Description entfernen
                    $description = preg_replace('/<img[^>]+src="([^"]+)"[^>]*>/i', '', $description, 1);
                }

                $feedItems[] = [
                    'title' => (string)$item->title,
                    'link' => (string)$item->link,
                    'pubDate' => (string)$item->pubDate,
                    'description' => $description,
                    'imgTag' => $imgTag
                ];
            }
        } else {
            $feedError = 'Feed konnte nicht gelesen werden.';
        }
    } else {
        $feedError = 'Feed konnte nicht geladen werden.';
    }
}
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <title><?php echo htmlspecialchars($feedTitle ?: 'Feed'); ?></title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <style>
        body {
            margin: 0;
            padding: 0;
            background: transparent;
            font-family: Arial, sans-serif;
            color: #222;
        }
        .feed-container {
            margin: 40px auto;
            background: rgba(255,255,255,0.0); /* transparent */
            border-radius: 16px;
            box-shadow: none;
            padding: 0;
            display: flex;
            flex-direction: column;
            align-items: center;
            width: 100%;
        }
        .feed-box {
            width: 600px;
            max-width: 98vw;
            background: rgba(255,255,255,0.7);
            border-radius: 16px;
            padding: 18px 18px 10px 18px;
            box-sizing: border-box;
            margin: 0 auto;
        }
        .feed-title {
            font-size: 22px;
            font-weight: bold;
            color: #222;
            margin-bottom: 18px;
            text-align: center;
        }
        .feed-list {
            list-style: none;
            padding: 0;
            margin: 0;
        }
        .feed-item {
            border-bottom: 1px solid #eee;
            padding: 14px 0;
        }
        .feed-item:last-child { border-bottom: none; }
        .feed-item-title {
            font-size: 17px;
            font-weight: bold;
            color: #0077cc;
            text-decoration: none;
        }
        .feed-item-date {
            font-size: 12px;
            color: #888;
            margin-bottom: 6px;
        }
        .feed-item-desc {
            color: #222;
            margin-top: 8px;
        }
        .error {
            color: #c00;
            font-weight: bold;
            margin-bottom: 10px;
            text-align: center;
        }
        @media (max-width: 700px) {
            .feed-box {
                width: 260px;
                min-width: 0;
                padding: 10px;
            }
        }
    </style>
</head>
<body>
<div class="feed-container">
    <div class="feed-box">
        <?php if ($feedError): ?>
            <div class="error"><?php echo htmlspecialchars($feedError); ?></div>
        <?php else: ?>
            <div class="feed-title"><?php echo htmlspecialchars($feedTitle ?: $feedUrl); ?></div>
            <ul class="feed-list">
                <?php foreach ($feedItems as $item): ?>
                    <li class="feed-item">
                        <a href="<?php echo htmlspecialchars($item['link']); ?>" target="_blank" class="feed-item-title"><?php echo htmlspecialchars($item['title']); ?></a>
                        <div class="feed-item-date"><?php echo date('d.m.Y H:i', strtotime($item['pubDate'])); ?></div>
                        <?php if (!empty($item['imgTag'])): ?>
                            <?php echo $item['imgTag']; ?>
                        <?php endif; ?>
                        <div class="feed-item-desc"><?php echo strip_tags($item['description'], '<b><i><u><br><p>'); ?></div>
                    </li>
                <?php endforeach; ?>
                <?php if (empty($feedItems)): ?>
                    <li><?php echo 'Keine Einträge gefunden.'; ?></li>
                <?php endif; ?>
            </ul>
        <?php endif; ?>
    </div>
</div>
</body>
</html>