<?php
session_start();

// Sprache wählen (GET-Parameter, Default: de)
$lang = 'de';
if (isset($_GET['lang']) && in_array($_GET['lang'], ['de', 'en', 'it', 'es', 'fr', 'pl', 'nl', 'da', 'bg'])) {
    $lang = $_GET['lang'];
}
$langFile = __DIR__ . "/feed_einstellungen/lang_{$lang}.php";
if (!file_exists($langFile)) $langFile = __DIR__ . "/feed_einstellungen/lang_de.php";
$L = require $langFile;

// Einstellungen laden
$settingsDir = __DIR__ . '/feed_einstellungen';
$settingsFile = $settingsDir . '/feed_einstellungen.json';
if (!is_dir($settingsDir)) mkdir($settingsDir, 0777, true);

$feedUrls = [];
if (file_exists($settingsFile)) {
    $json = file_get_contents($settingsFile);
    $decoded = json_decode($json, true);
    if (is_array($decoded)) $feedUrls = $decoded;
}
for ($i = 0; $i < 5; $i++) {
    if (!isset($feedUrls[$i])) $feedUrls[$i] = '';
}

// Feed-Auswahl
$selectedFeed = isset($_GET['feed']) && is_numeric($_GET['feed']) && $_GET['feed'] >= 0 && $_GET['feed'] < 5 ? intval($_GET['feed']) : 0;
$feedUrl = trim($feedUrls[$selectedFeed]);

// Feed laden
$feedItems = [];
$feedTitle = '';
$feedError = '';
if ($feedUrl) {
    $feedContent = @file_get_contents($feedUrl);
    if ($feedContent !== false) {
        $rss = @simplexml_load_string($feedContent);
        if ($rss !== false && isset($rss->channel)) {
            $feedTitle = (string)$rss->channel->title;
            foreach ($rss->channel->item as $item) {
                $feedItems[] = [
                    'title' => (string)$item->title,
                    'link' => (string)$item->link,
                    'pubDate' => (string)$item->pubDate,
                    'description' => (string)$item->description
                ];
            }
        } else {
            $feedError = $L['feed_parse_error'];
        }
    } else {
        $feedError = $L['feed_load_error'];
    }
}
?>
<!DOCTYPE html>
<html lang="<?php echo $lang; ?>">
<head>
    <meta charset="UTF-8">
    <title><?php echo $L['reader_title']; ?></title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <style>
        body { font-family: Arial, sans-serif; font-size: 14px; background-color: #333; color: #FFF; margin: 0; padding: 20px; }
        .container { display: flex; flex-direction: column; align-items: center; }
        .feed-box {
            background: #fff;
            color: #000;
            padding: 30px 30px 20px 30px;
            border-radius: 16px;
            margin-top: 40px;
            min-width: 340px;
            max-width: 600px;
            box-shadow: 0 2px 16px rgba(0,0,0,0.15);
        }
        .feed-title { font-size: 22px; font-weight: bold; color: #222; margin-bottom: 18px; text-align: center; }
        .feed-list { list-style: none; padding: 0; margin: 0; }
        .feed-item { border-bottom: 1px solid #eee; padding: 16px 0; }
        .feed-item:last-child { border-bottom: none; }
        .feed-item-title { font-size: 18px; font-weight: bold; color: #0077cc; text-decoration: none; }
        .feed-item-date { font-size: 12px; color: #888; margin-bottom: 6px; }
        .feed-item-desc { color: #222; margin-top: 8px; }
        .controls-row {
            display: flex;
            gap: 12px;
            align-items: center;
            margin-bottom: 10px;
            justify-content: center;
            flex-wrap: wrap;
        }
        .controls {
            display: flex;
            gap: 12px;
            align-items: center;
            justify-content: center;
            margin-bottom: 18px;
            flex-wrap: wrap;
        }
        select, button {
            font-size: 16px;
            padding: 7px 14px;
            border-radius: 7px;
            border: 2px solid #CCC;
        }
        button {
            background: #F01500;
            color: #FFF;
            font-weight: bold;
            border: 2px solid #FFF;
            cursor: pointer;
        }
        button:hover { background: #FF4A24; }
        .settings-btn {
            background: #0077cc;
            color: #fff !important;
            border: 2px solid #fff;
            font-weight: bold;
            cursor: pointer;
            text-decoration: none;
            padding: 7px 14px;
            border-radius: 7px;
            display: inline-block;
            transition: background 0.2s;
        }
        .settings-btn:hover { background: #3399ff; }
        .lang-switch { margin-bottom: 20px; text-align: right; width: 100%; }
        .lang-switch a {
            color: #FF9800 !important;
            text-decoration: underline;
            margin-left: 10px;
            font-weight: bold;
        }
        .error { color: #c00; font-weight: bold; margin-bottom: 10px; }
        @media (max-width: 700px) {
            .feed-box { min-width: 0; width: 98vw; padding: 10px; }
            .controls-row, .controls { flex-direction: column; gap: 8px; }
        }
    </style>
</head>
<body>
<div class="container">
    <div class="lang-switch">
        <a href="?lang=de&feed=<?php echo $selectedFeed; ?>">Deutsch</a> |
        <a href="?lang=en&feed=<?php echo $selectedFeed; ?>">English</a> |
        <a href="?lang=it&feed=<?php echo $selectedFeed; ?>">Italiano</a> |
        <a href="?lang=fr&feed=<?php echo $selectedFeed; ?>">Français</a> |
        <a href="?lang=es&feed=<?php echo $selectedFeed; ?>">Español</a> |
        <a href="?lang=pl&feed=<?php echo $selectedFeed; ?>">Polski</a> |
        <a href="?lang=nl&feed=<?php echo $selectedFeed; ?>">Nederlands</a> |
        <a href="?lang=da&feed=<?php echo $selectedFeed; ?>">Dansk</a> |
        <a href="?lang=bg&feed=<?php echo $selectedFeed; ?>">Български</a>
    </div>
    <div class="feed-box">
        <div class="controls-row">
            <form method="get" style="display:inline;">
                <input type="hidden" name="lang" value="<?php echo $lang; ?>">
                <input type="hidden" name="feed" value="<?php echo $selectedFeed; ?>">
                <button type="submit"><?php echo $L['refresh']; ?></button>
            </form>
            <a href="feed_einstellungen/feed_reader_settings.php?lang=<?php echo $lang; ?>" class="settings-btn"><?php echo $L['settings']; ?></a>
        </div>
        <form method="get" class="controls" style="margin-bottom:20px;">
            <input type="hidden" name="lang" value="<?php echo $lang; ?>">
            <label for="feed"><?php echo $L['select_feed']; ?></label>
            <select name="feed" id="feed" onchange="this.form.submit()">
                <?php for ($i = 0; $i < 5; $i++): ?>
                    <option value="<?php echo $i; ?>" <?php if ($selectedFeed == $i) echo 'selected'; ?>>
                        <?php echo $feedUrls[$i] ? htmlspecialchars($feedUrls[$i]) : $L['feed_slot'] . ' ' . ($i+1); ?>
                    </option>
                <?php endfor; ?>
            </select>
        </form>
        <?php if ($feedError): ?>
            <div class="error"><?php echo $feedError; ?></div>
        <?php endif; ?>
        <?php if ($feedUrl && !$feedError): ?>
            <div class="feed-title"><?php echo htmlspecialchars($feedTitle ?: $feedUrl); ?></div>
            <ul class="feed-list">
                <?php foreach ($feedItems as $item): ?>
                    <li class="feed-item">
                        <a href="<?php echo htmlspecialchars($item['link']); ?>" target="_blank" class="feed-item-title"><?php echo htmlspecialchars($item['title']); ?></a>
                        <div class="feed-item-date"><?php echo date($lang == 'de' ? 'd.m.Y H:i' : 'Y-m-d H:i', strtotime($item['pubDate'])); ?></div>
                        <div class="feed-item-desc"><?php echo strip_tags($item['description'], '<b><i><u><br><p>'); ?></div>
                    </li>
                <?php endforeach; ?>
                <?php if (empty($feedItems)): ?>
                    <li><?php echo $L['no_items']; ?></li>
                <?php endif; ?>
            </ul>
        <?php elseif (!$feedUrl): ?>
            <div class="error"><?php echo $L['no_feed_selected']; ?></div>
        <?php endif; ?>
    </div>
</div>
<p style="text-align: center;font-family:Arial, sans-serif;font-size:9px;color: #fff;">FEED-Raeader 1.0 &#10070; &copy; S.G.Schiffer 2025 - <a style="color:#FF9800;text-decoration:none;" href="https://www.sgs-visual.de" target="_blank">sgs-visual.de</a></p>
</body>
</html>