<?php
// feed_writer.php
session_start();

// Sprache wählen (GET-Parameter, Default: de)
$lang = 'de';
if (isset($_GET['lang']) && in_array($_GET['lang'], ['de', 'bg', 'en', 'it', 'es', 'fr', 'pl', 'da', 'nl'])) {
    $lang = $_GET['lang'];
}
$langFile = __DIR__ . "/feed/lang/{$lang}.php";
if (!file_exists($langFile)) $langFile = __DIR__ . "/feed/lang/de.php";
$L = require $langFile;

// Feed-Name (wird als Titel im RSS-Feed verwendet)
$feedName = "";

// Passwort für Login
$password = "passwort";
$message = "";

// Login-Logik
if (isset($_POST['login']) && isset($_POST['password'])) {
    if ($_POST['password'] === $password) {
        $_SESSION['loggedIn'] = true;
        $message = $L['login_success'];
    } else {
        $message = $L['login_error'];
    }
}

if (isset($_POST['logout'])) {
    $_SESSION['loggedIn'] = false;
    session_destroy();
    $message = $L['logout_success'];
}

$loggedIn = isset($_SESSION['loggedIn']) && $_SESSION['loggedIn'] === true;

date_default_timezone_set('Europe/Berlin');
function getImageFiles($dir = 'feed/imgs') {
    $files = [];
    if (is_dir($dir)) {
        foreach (scandir($dir) as $file) {
            if (in_array(strtolower(pathinfo($file, PATHINFO_EXTENSION)), ['jpg', 'jpeg', 'png', 'gif', 'webp'])) {
                $files[] = $file;
            }
        }
    }
    return $files;
}

// JSON-Feed-Datei
$jsonDir = 'feed/data';
$jsonFile = $jsonDir . '/feeds.json';
if (!is_dir($jsonDir)) mkdir($jsonDir, 0777, true);

// Schriftwerte JSON laden/speichern
$schriftwerteDir = 'feed/data';
$schriftwerteFile = $schriftwerteDir . '/schriftwerte.json';
if (!is_dir($schriftwerteDir)) mkdir($schriftwerteDir, 0777, true);
$schriftwerte = [
    'feed_font' => 'Arial, sans-serif',
    'feed_fontsize' => '14px',
    'feed_title_color' => '#000000'
];
if (file_exists($schriftwerteFile)) {
    $json = file_get_contents($schriftwerteFile);
    $decoded = json_decode($json, true);
    if (is_array($decoded)) $schriftwerte = array_merge($schriftwerte, $decoded);
}

// Feed-Name persistent speichern/laden
$feedNameFile = $jsonDir . '/feedname.txt';
if (isset($_POST['set_feedname']) && isset($_POST['feed_name'])) {
    $feedName = trim($_POST['feed_name']);
    file_put_contents($feedNameFile, $feedName);
    header("Location: " . $_SERVER['PHP_SELF'] . "?lang=" . $lang);
    exit;
}
if (file_exists($feedNameFile)) {
    $feedName = trim(file_get_contents($feedNameFile));
}

// Upload-Meldung
$uploadMessage = '';
if (isset($_POST['upload_image_btn']) && isset($_FILES['upload_image']) && $_FILES['upload_image']['error'] !== UPLOAD_ERR_NO_FILE) {
    $uploadDir = 'feed/imgs/';
    $uploadFile = $uploadDir . basename($_FILES['upload_image']['name']);
    $ext = strtolower(pathinfo($uploadFile, PATHINFO_EXTENSION));
    if (in_array($ext, ['jpg', 'jpeg', 'png', 'gif', 'webp'])) {
        if (move_uploaded_file($_FILES['upload_image']['tmp_name'], $uploadFile)) {
            $uploadMessage = '<span style="color:#0f0;">' . $L['upload_success'] . htmlspecialchars(basename($_FILES['upload_image']['name'])) . '</span>';
        } else {
            $uploadMessage = '<span style="color:#f00;">' . $L['upload_error'] . '</span>';
        }
    } else {
        $uploadMessage = '<span style="color:#f00;">' . $L['upload_invalid'] . '</span>';
    }
}

// Feed laden (JSON)
$feeds = [];
if (file_exists($jsonFile)) {
    $feeds = json_decode(file_get_contents($jsonFile), true);
    if (!is_array($feeds)) $feeds = [];
}
$feedSaved = false;
$saveMessage = '';
$editIndex = null;
$editData = [
    'feed_title' => '',
    'feed_link' => '',
    'feed_date' => date('Y-m-d'),
    'feed_image' => '',
    'feed_content' => '',
    'feed_font' => $schriftwerte['feed_font'],
    'feed_fontsize' => $schriftwerte['feed_fontsize'],
    'feed_title_color' => $schriftwerte['feed_title_color']
];

// --- Bearbeitungsindex bestimmen ---
if (isset($_GET['edit']) && is_numeric($_GET['edit'])) {
    $editIndex = intval($_GET['edit']);
}

// --- Feed löschen ---
if (isset($_POST['delete_feed']) && isset($_POST['delete_index']) && is_numeric($_POST['delete_index'])) {
    $deleteIndex = intval($_POST['delete_index']);
    if (isset($feeds[$deleteIndex])) {
        array_splice($feeds, $deleteIndex, 1);
        file_put_contents($jsonFile, json_encode($feeds, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));
        // XML synchronisieren nach Löschung
        $feedFile = 'feed/feed.xml';
        $rss = new SimpleXMLElement('<?xml version="1.0" encoding="UTF-8"?><rss version="2.0"></rss>');
        $channel = $rss->addChild('channel');
        $channel->addChild('title', htmlspecialchars($feedName));
        $channel->addChild('link', 'https://www.sgs-visual.de');
        $channel->addChild('description', 'Feed-Writer RSS Feed');
        foreach ($feeds as $f) {
            $item = $channel->addChild('item');
            $item->addChild('title', htmlspecialchars($f['feed_title']));
            $item->addChild('link', htmlspecialchars($f['feed_link']));
            $dateObj = DateTime::createFromFormat('Y-m-d', $f['feed_date']);
            $pubDate = $dateObj ? $dateObj->format('D, d M Y 00:00:00 O') : date('D, d M Y 00:00:00 O');
            $item->addChild('pubDate', $pubDate);
            $content = '<div style="font-family:' . htmlspecialchars($f['feed_font']) . ';font-size:' . htmlspecialchars($f['feed_fontsize']) . ';color:#000;text-align:left;">';
            if ($f['feed_image']) {
                $content .= '<img src="feed/imgs/' . htmlspecialchars($f['feed_image']) . '" style="max-width:200px;height:auto;display:block;margin:0 0 10px 0;text-align:left;" class="feed-preview-img">';
            }
            $content .= $f['feed_content'] . '</div><br><div style="text-align:center;">--- RSS Feed ---</div><br>';
            $item->addChild('description', '<![CDATA[' . $content . ']]>');
        }
        $rss->asXML($feedFile);
        header("Location: " . $_SERVER['PHP_SELF'] . "?lang=" . $lang);
        exit;
    }
}

// --- Felder für Bearbeitung füllen ---
if ($editIndex !== null && isset($feeds[$editIndex])) {
    $editData = $feeds[$editIndex];
}

// Feed speichern oder aktualisieren
if (isset($_POST['save_feed'])) {
    $feedTitle = trim($_POST['feed_title'] ?? '');
    $feedLink = trim($_POST['feed_link'] ?? '');
    $feedDate = trim($_POST['feed_date'] ?? '');
    $feedImage = trim($_POST['feed_image'] ?? '');
    $feedContent = trim($_POST['feed_content'] ?? '');
    $feedFont = $_POST['feed_font'] ?? $schriftwerte['feed_font'];
    $feedFontSize = $_POST['feed_fontsize'] ?? $schriftwerte['feed_fontsize'];
    $feedTitleColor = $_POST['feed_title_color'] ?? $schriftwerte['feed_title_color'];
    $editIndex = isset($_POST['edit_index']) && $_POST['edit_index'] !== '' ? intval($_POST['edit_index']) : null;

    // Schriftwerte speichern
    $schriftwerte = [
        'feed_font' => $feedFont,
        'feed_fontsize' => $feedFontSize,
        'feed_title_color' => $feedTitleColor
    ];
    file_put_contents($schriftwerteFile, json_encode($schriftwerte, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));

    // Feed-Array für JSON
    $feedArr = [
        'feed_title' => $feedTitle,
        'feed_link' => $feedLink,
        'feed_date' => $feedDate,
        'feed_image' => $feedImage,
        'feed_content' => $feedContent,
        'feed_font' => $feedFont,
        'feed_fontsize' => $feedFontSize,
        'feed_title_color' => $feedTitleColor
    ];

    if ($editIndex !== null && isset($feeds[$editIndex])) {
        $feeds[$editIndex] = $feedArr;
        $saveMessage = $L['feed_updated'];
    } else {
        $feeds[] = $feedArr;
        $editIndex = count($feeds) - 1;
        $saveMessage = $L['feed_saved'];
    }
    file_put_contents($jsonFile, json_encode($feeds, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));
    $feedSaved = true;

    // --- XML synchronisieren ---
    $feedFile = 'feed/feed.xml';
    $rss = new SimpleXMLElement('<?xml version="1.0" encoding="UTF-8"?><rss version="2.0"></rss>');
    $channel = $rss->addChild('channel');
    $channel->addChild('title', htmlspecialchars($feedName));
    $channel->addChild('link', 'https://www.sgs-visual.de');
    $channel->addChild('description', 'Feed-Writer RSS Feed');
    foreach ($feeds as $f) {
        $item = $channel->addChild('item');
        $item->addChild('title', htmlspecialchars($f['feed_title']));
        $item->addChild('link', htmlspecialchars($f['feed_link']));
        $dateObj = DateTime::createFromFormat('Y-m-d', $f['feed_date']);
        $pubDate = $dateObj ? $dateObj->format('D, d M Y 00:00:00 O') : date('D, d M Y 00:00:00 O');
        $item->addChild('pubDate', $pubDate);
        $content = '<div style="font-family:' . htmlspecialchars($f['feed_font']) . ';font-size:' . htmlspecialchars($f['feed_fontsize']) . ';color:#000;text-align:left;">';
        if ($f['feed_image']) {
            $content .= '<img src="feed/imgs/' . htmlspecialchars($f['feed_image']) . '" style="max-width:200px;height:auto;display:block;margin:0 0 10px 0;text-align:left;" class="feed-preview-img">';
        }
        $content .= $f['feed_content'] . '</div><br><div style="text-align:center;">--- RSS Feed ---</div><br>';
        $item->addChild('description', '<![CDATA[' . $content . ']]>');
    }
    $rss->asXML($feedFile);

    header("Location: redirect.php?edit=" . $editIndex . "&lang=" . $lang);
    exit;
}

$imageFiles = getImageFiles();
?>
<!DOCTYPE html>
<html lang="<?php echo $lang; ?>">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $L['app_title']; ?></title>
    <style>
        body { font-family: Arial, sans-serif; font-size: 14px; background-color: #333; color: #FFF; margin: 5; padding: 20px; }
        .ueberschrift { font-size: 16px; font-weight: bold; color: #FFF; padding: 2px; }
        .infotext { font-size: 12px; color: #FFF; padding: 4px; }
        .btnAlle { padding: 8px 16px; border: none; border-radius: 8px; cursor: pointer; display: inline-flex; align-items: center; font-size: 16px; font-weight: bold; }
        .btn-login { background-color: #F01500; color: #FFF; border: 2px solid #FFF; }
        .btn-login:hover { background-color: #FF4A24; }
        .btn-logout { background-color: #F01500; color: #FFF; border: 2px solid #FFF; }
        .btn-logout:hover { background-color: #FF4A24; }
        .btn-edit { background-color: #0077cc; color: #fff; border: 2px solid #fff; border-radius: 8px; padding: 4px 14px; font-size: 14px; font-weight: bold; cursor: pointer; margin-left: 10px; }
        .btn-edit:hover { background-color: #3399ff; }
        .btn-delete { background-color: #cc0000; color: #fff; border: 2px solid #fff; border-radius: 8px; padding: 4px 14px; font-size: 14px; font-weight: bold; cursor: pointer; margin-left: 10px; }
        .btn-delete:hover { background-color: #ff3333; }
        .login-form { max-width: 400px; margin: 100px auto; text-align: center; }
        .message { padding: 10px; margin-bottom: 20px; background-color: rgba(255,255,255,0.1); border-radius: 4px; text-align: center; }
        .success { background-color: #4CAF50; }
        .error { background-color: #F44336; }
        input[type="password"], input[type="text"], input[type="url"], input[type="date"], select, textarea {
            font-family: Tahoma, sans-serif; font-size: 16px; padding: 8px; border-radius: 6px; border: 2px solid #CCC; margin-bottom: 10px; margin-top: 10px;
        }
        input[type="color"] { width: 40px; padding: 4px; border-radius: 6px; border: 2px solid #CCC; margin-bottom: 10px; margin-top: 10px; }
        label { display: block; margin-bottom: 0px; margin-top: 18px; }
        .icon { width: 20px; height: 20px; margin-right: 0; }
        .icon_auge { width: 32px; height: 24px; margin-right: 0; }
        .icon-btn { background: none; border: none; padding: 0; margin: 0 4px 0 0; cursor: pointer; outline: none; box-shadow: none; display: inline-block; }
        .icon-btn:focus { outline: none; }
        .upload-section { display: flex; align-items: center; gap: 10px; margin-top: 0; margin-bottom: 0; }
        .upload-message { font-size: 14px; margin-top: 8px; margin-bottom: 8px; color: #FFD700; }
        .flex-row { display: flex; align-items: center; gap: 10px; margin-bottom: 10px; margin-top: 10px; }
        select#feed_font, select#feed_fontsize { width: auto; min-width: 90px; max-width: 160px; }
        select#feed_fontsize { min-width: 60px; max-width: 80px; }
        input#feed_title, input#feed_link { width: 300px; box-sizing: border-box; }
        textarea#feed_content { width: 400px; box-sizing: border-box; }
        select#feed_image { width: 180px; min-width: 180px; max-width: 180px; }
        .feed-preview-window { background: #fff; color: #000; padding: 20px; border-radius: 12px; margin-top: 30px; min-height: 120px; max-width: 500px; margin-left: auto; margin-right: auto; }
        .feed-preview-title { font-size: 18px; font-weight: bold; text-decoration: none; color: inherit; display: block; text-align: left; }
        .feed-preview-date { font-size: 12px; color: #888; text-align: left; }
        .feed-preview-content { color: #000; text-align: left; }
        .feed-preview-img { max-width: 200px !important; height: auto !important; display: block; margin: 0 0 10px 0 !important; text-align: left !important; }
        .feed-edit-select-row { display: flex; align-items: center; gap: 10px; margin-bottom: 20px; }
        .feed-edit-select-row label { margin-top: 0; margin-bottom: 0; }
        .feed-delete-select-row { display: flex; align-items: center; gap: 10px; margin-bottom: 20px; margin-top: -10px; }
        .feed-delete-select-row label { margin-top: 0; margin-bottom: 0; }
        .lang-switch { margin-bottom: 20px; text-align: right; }
        .lang-switch a { color: #FFD700; text-decoration: none; margin-left: 10px; }
    </style>
</head>
<body>
    <div class="container">
        <div class="lang-switch">
    <a href="?lang=de">Deutsch</a> |
    <a href="?lang=en">English</a> |
    <a href="?lang=it">Italiano</a> |
    <a href="?lang=fr">Français</a> |
    <a href="?lang=es">Español</a> |
    <a href="?lang=pl">Polski</a> |
    <a href="?lang=nl">Nederlands</a> |
    <a href="?lang=da">Dansk</a> |
    <a href="?lang=bg">Български</a>

        </div>
        <?php if (!$loggedIn): ?>
            <div class="login-form">
                <div style="font-size:24px; margin-top:20px; font-weight: 600;"><sub><img src="feed/icons/feed_icon.png" width="24px" height=24px"></sub> <?php echo $L['login_title']; ?></div>
                <p class="infotext"><?php echo $L['login_info']; ?></p>
                <?php if (!empty($message)): ?>
                    <div class="message <?php echo strpos($message, $L['login_success']) !== false ? 'success' : 'error'; ?>"><?php echo $message; ?></div>
                <?php endif; ?>
                <form method="post" action="<?php echo $_SERVER['PHP_SELF'] . '?lang=' . $lang; ?>">
                    <div style="display:flex; align-items:center; justify-content:center;">
                        <input type="password" name="password" id="passwordInput" placeholder="<?php echo $L['password_placeholder']; ?>" required>
                        <button type="button" id="togglePassword" style="background:transparent; border:none; cursor:pointer; margin-left:10px; padding:0;">
                            <img src="feed/icons/anzeigen.png" alt="<?php echo $L['show_password']; ?>" id="toggleIcon" class="icon_auge">
                        </button>
                    </div>
                    <div style="margin-top: 15px;">
                        <button type="submit" name="login" class="btnAlle btn-login">
                            <img src="feed/icons/login.png" alt="Login" class="icon">&nbsp;<?php echo $L['login']; ?>
                        </button>
                    </div>
                    <div style="font-size:9px; margin-top:20px;"><?php echo $L['copyright']; ?></div>
                </form>
            </div>
        <?php else: ?>

<div style="width: 50%; margin: 0 auto;">



<?php if (empty($feedName)): ?>
    <form method="post" style="background:#222;padding:20px;border-radius:12px;max-width:400px;margin:40px auto;">
        <div class="ueberschrift" style="margin-bottom:10px;"><?php echo $L['feed_name_set']; ?></div>
        <label for="feed_name"><?php echo $L['set_feedname']; ?></label>
        <input type="text" name="feed_name" id="feed_name" placeholder="<?php echo $L['feed_name_placeholder']; ?>" required>
        <div style="margin-top:15px;">
            <button type="submit" name="set_feedname" class="btnAlle btn-login">
                <img src="feed/icons/speichern.png" class="icon">&nbsp;<?php echo $L['save']; ?>
            </button>
        </div>
    </form>
<?php else: ?>
    <div style="margin-bottom:20px;">
        <span class="ueberschrift"><?php echo $L['feed_name_label']; ?></span>
        <span style="font-size:16px;color:#FFD700;font-weight:bold;"><?php echo htmlspecialchars($feedName); ?></span>
    </div>
<!-- Auswahlfeld für Feed-Bearbeitung -->
<form method="get" class="feed-edit-select-row" style="margin-bottom:0;">
    <input type="hidden" name="lang" value="<?php echo $lang; ?>">
    <label for="edit"><?php echo $L['feed_select']; ?></label>
    <select name="edit" id="edit">
        <option value=""><?php echo $L['new_feed']; ?></option>
        <?php foreach ($feeds as $idx => $item): ?>
            <option value="<?php echo $idx; ?>" <?php if($editIndex !== null && $editIndex == $idx) echo 'selected'; ?>><?php echo htmlspecialchars($item['feed_title']); ?></option>
        <?php endforeach; ?>
    </select>
    <button type="submit" class="btn-edit"><img src="feed/icons/generator_icon_weiss.gif" width="12px" height="12px" class="icon" alt="<?php echo $L['edit']; ?>"> <?php echo $L['edit']; ?></button>
</form>
<!-- Feed löschen -->
<form method="post" class="feed-delete-select-row" onsubmit="return confirm('<?php echo $L['delete_confirm']; ?>');">
    <label for="delete_index"><?php echo $L['feed_delete_select']; ?>&nbsp;&emsp;</label>
    <select name="delete_index" id="delete_index">
        <option value=""><?php echo $L['feed_select']; ?></option>
        <?php foreach ($feeds as $idx => $item): ?>
            <option value="<?php echo $idx; ?>"><?php echo htmlspecialchars($item['feed_title']); ?></option>
        <?php endforeach; ?>
    </select>
    <button type="submit" name="delete_feed" class="btn-delete">
        <img src="feed/icons/loeschen.png" width="12px" height="12px" class="icon" alt="<?php echo $L['delete']; ?>">
        <?php echo $L['delete']; ?>
    </button>
    <input type="hidden" name="lang" value="<?php echo $lang; ?>">
</form>
<form method="post" enctype="multipart/form-data" style="background:#222;padding:20px;border-radius:12px;">
    <div class="ueberschrift" style="margin-bottom:10px;"><?php echo ($editIndex !== null) ? $L['edit_feed'] : $L['new_feed']; ?></div>
    <?php if ($feedSaved): ?>
        <div class="message success"><?php echo $saveMessage; ?></div>
    <?php endif; ?>
    <input type="hidden" name="edit_index" value="<?php echo ($editIndex !== null) ? intval($editIndex) : ''; ?>">
    <input type="hidden" name="lang" value="<?php echo $lang; ?>">
    <label for="feed_title"><?php echo $L['feed_title_label']; ?></label>
    <input type="text" name="feed_title" id="feed_title" placeholder="<?php echo $L['feed_title_placeholder']; ?>" required value="<?php echo htmlspecialchars($editData['feed_title']); ?>">
    <label for="feed_link"><?php echo $L['feed_link_label']; ?></label>
    <input type="url" name="feed_link" id="feed_link" placeholder="<?php echo $L['feed_link_placeholder']; ?>" required value="<?php echo htmlspecialchars($editData['feed_link']); ?>">
    <label for="feed_date"><?php echo $L['feed_date_label']; ?></label>
    <input type="date" name="feed_date" id="feed_date" value="<?php echo htmlspecialchars($editData['feed_date']); ?>" required>
    <div class="upload-section">
        <label for="feed_image" style="margin-top:0;"><?php echo $L['feed_image_label']; ?></label>
</div>
    <div class="upload-section">
        <select name="feed_image" id="feed_image">
            <option value=""><?php echo $L['no_image']; ?></option>
            <?php foreach ($imageFiles as $img): ?>
                <option value="<?php echo htmlspecialchars($img); ?>" <?php if ($editData['feed_image'] === $img) echo 'selected'; ?>><?php echo htmlspecialchars($img); ?></option>
            <?php endforeach; ?>
        </select>
        <input type="file" name="upload_image" accept="image/*" style="width:auto;margin-top:0;margin-bottom:0;">

   </div>
    <div class="upload-section">
        <button type="submit" name="upload_image_btn" class="btnAlle btn-login" style="padding:4px 16px;font-size:14px;margin-top:0;margin-bottom:0;margin-left:180px;"><?php echo $L['upload_image']; ?></button>
    </div>
    <?php if (!empty($uploadMessage)): ?>
        <div class="upload-message"><?php echo $uploadMessage; ?></div>
    <?php endif; ?>
    <div class="flex-row">
        <label for="feed_font" style="margin-top:0;"><?php echo $L['font_label']; ?></label>
        <select name="feed_font" id="feed_font">
            <option value="Helvetica, Arial, sans-serif" <?php if($editData['feed_font']=='Helvetica, Arial, sans-serif') echo 'selected'; ?>>Helvetica</option>
            <option value="Tahoma, Geneva, sans-serif" <?php if($editData['feed_font']=='Tahoma, Geneva, sans-serif') echo 'selected'; ?>>Tahoma</option>
            <option value="Verdana, Geneva, sans-serif" <?php if($editData['feed_font']=='Verdana, Geneva, sans-serif') echo 'selected'; ?>>Verdana</option>
            <option value="Arial, sans-serif" <?php if($editData['feed_font']=='Arial, sans-serif') echo 'selected'; ?>>Arial</option>
        </select>
        <label for="feed_fontsize" style="margin-top:0;"><?php echo $L['fontsize_label']; ?></label>
        <select name="feed_fontsize" id="feed_fontsize">
            <?php for ($i=10; $i<=20; $i++): ?>
                <option value="<?php echo $i; ?>px" <?php if($editData['feed_fontsize']==$i.'px') echo 'selected'; ?>><?php echo $i; ?>px</option>
            <?php endfor; ?>
        </select>
        <label for="feed_title_color" style="margin-top:0;"><?php echo $L['title_color_label']; ?></label>
        <input type="color" name="feed_title_color" id="feed_title_color" value="<?php echo htmlspecialchars($editData['feed_title_color']); ?>">
    </div>
    <label for="feed_content"><strong style="font-size:16px;"><?php echo $L['feed_content_label']; ?></strong></label>
    <div class="editor-icons-info">
        <span><?php echo $L['editor_info']; ?></span>
    </div>
    <div style="display:flex;align-items:center;gap:5px;margin-bottom:5px;">
        <button type="button" class="icon-btn" onclick="formatText('bold')" title="Fett"><img src="feed/icons/bold.png" class="icon"></button>
        <button type="button" class="icon-btn" onclick="formatText('italic')" title="Kursiv"><img src="feed/icons/italic.png" class="icon"></button>
        <button type="button" class="icon-btn" onclick="formatText('underline')" title="Unterstrichen"><img src="feed/icons/underline.png" class="icon"></button>
        <button type="button" class="icon-btn" onclick="insertBr()" title="Absatz"><img src="feed/icons/br.png" class="icon"></button>
    </div>
    <textarea name="feed_content" id="feed_content" rows="6" required><?php echo htmlspecialchars($editData['feed_content']); ?></textarea>
    <div style="margin-top:15px;">
        <button type="submit" name="save_feed" class="btnAlle btn-login">
            <img src="feed/icons/speichern.png" class="icon">&nbsp;<?php echo ($editIndex !== null) ? $L['update'] : $L['save']; ?>
        </button>
    </div>
</form>
<!-- Feed-Vorschau -->
<?php if ($editIndex !== null && isset($feeds[$editIndex])): ?>
<div id="feedPreviewWindow" class="feed-preview-window">
    <div class="ueberschrift" style="color:#000;margin-bottom:10px;"><?php echo $L['feed_preview']; ?></div>
    <?php
    $f = $feeds[$editIndex];
    $dateObj = DateTime::createFromFormat('Y-m-d', $f['feed_date']);
    $dateDE = $dateObj ? $dateObj->format($lang == 'de' ? 'd.m.Y' : 'Y-m-d') : '';
    $titleColor = $f['feed_title_color'] ?? '#000';
    echo '<div style="display:block;width:100%;">';
    echo '<a href="' . htmlspecialchars($f['feed_link']) . '" target="_blank" class="feed-preview-title" style="color:' . htmlspecialchars($titleColor) . ';">' . htmlspecialchars($f['feed_title']) . '</a>';
    echo '<div class="feed-preview-date">' . $dateDE . '</div>';
    $content = '';
    if ($f['feed_image']) {
        $content .= '<img src="feed/imgs/' . htmlspecialchars($f['feed_image']) . '" class="feed-preview-img">';
    }
    $content .= $f['feed_content'] . '<br><div style="text-align:center;">--- RSS Feed ---</div><br>';
    echo '<div class="feed-preview-content">' . $content . '</div>';
    echo '</div>';
    ?>
</div>
<?php endif; ?>
<?php endif; // Feed-Name gesetzt ?>
<script>
function formatText(command) {
    var textarea = document.getElementById('feed_content');
    var start = textarea.selectionStart;
    var end = textarea.selectionEnd;
    var selected = textarea.value.substring(start, end);
    var before = textarea.value.substring(0, start);
    var after = textarea.value.substring(end);
    var tagOpen = '', tagClose = '';
    if (command === 'bold') { tagOpen = '<b>'; tagClose = '</b>'; }
    if (command === 'italic') { tagOpen = '<i>'; tagClose = '</i>'; }
    if (command === 'underline') { tagOpen = '<u>'; tagClose = '</u>'; }
    textarea.value = before + tagOpen + selected + tagClose + after;
    textarea.focus();
    textarea.selectionStart = start + tagOpen.length;
    textarea.selectionEnd = end + tagOpen.length;
}
function insertBr() {
    var textarea = document.getElementById('feed_content');
    var start = textarea.selectionStart;
    var before = textarea.value.substring(0, start);
    var after = textarea.value.substring(start);
    textarea.value = before + '<br>' + after;
    textarea.focus();
    textarea.selectionStart = textarea.selectionEnd = start + 4;
}
document.addEventListener('DOMContentLoaded', function() {
    var passwordInput = document.getElementById('passwordInput');
    var togglePassword = document.getElementById('togglePassword');
    var toggleIcon = document.getElementById('toggleIcon');
    if (passwordInput) passwordInput.focus();
    if (togglePassword && passwordInput && toggleIcon) {
        togglePassword.addEventListener('click', function(e) {
            e.preventDefault();
            if (passwordInput.type === 'password') {
                passwordInput.type = 'text';
                toggleIcon.src = 'feed/icons/verbergen.png';
                toggleIcon.alt = '<?php echo $L['hide_password']; ?>';
            } else {
                passwordInput.type = 'password';
                toggleIcon.src = 'feed/icons/anzeigen.png';
                toggleIcon.alt = '<?php echo $L['show_password']; ?>';
            }
        });
    }
});
</script>
            <!-- ##########  Skript FEED Writer Ende  ########## -->
            <form method="post" style="margin-top:30px;">
                <input type="hidden" name="lang" value="<?php echo $lang; ?>">
                <button type="submit" name="logout" class="btnAlle btn-logout">
                    <img src="feed/icons/logout.png" alt="Logout" class="icon">&nbsp;<?php echo $L['logout']; ?>
                </button>
            </form>
        <?php endif; ?>
    </div>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
        const passwordInput = document.getElementById('passwordInput');
        const togglePassword = document.getElementById('togglePassword');
        const toggleIcon = document.getElementById('toggleIcon');
        let visible = false;

        if (togglePassword && passwordInput && toggleIcon) {
            togglePassword.addEventListener('click', function() {
                visible = !visible;
                if (visible) {
                    passwordInput.type = 'text';
                    toggleIcon.src = 'feed/icons/verbergen.png';
                    toggleIcon.alt = '<?php echo $L['hide_password']; ?>';
                } else {
                    passwordInput.type = 'password';
                    toggleIcon.src = 'feed/icons/anzeigen.png';
                    toggleIcon.alt = '<?php echo $L['show_password']; ?>';
                }
            });
        }
    });
    </script>
<p style="text-align: center;font-family:Arial, sans-serif;font-size:9px;color: #fff;">FEED-Writer 1.0 &#10070; &copy; S.G.Schiffer 2025 - <a style="color:#FF9800;text-decoration:none;" href="https://www.sgs-visual.de" target="_blank">sgs-visual.de</a></p>
</div>
</body>
</html>